@@ -7,7 +7,6 @@ sentry.web.views
 """
 import logging
 
-from django.db.models import Q
 from django.http import HttpResponse, HttpResponseBadRequest, \
   HttpResponseForbidden
 from django.views.decorators.csrf import csrf_exempt
@@ -18,12 +17,12 @@ from sentry.coreapi import project_from_auth_vars, project_from_api_key_and_id,
   project_from_id, decode_and_decompress_data, safely_load_json_string, \
   validate_data, insert_data_to_database, APIError, APIUnauthorized, \
   extract_auth_vars, InvalidTimestamp
-from sentry.models import Group, GroupBookmark, Project, View
+from sentry.models import Group, GroupBookmark, Project, View, ProjectDomain
 from sentry.utils import json
+from sentry.utils.http import is_same_domain
 from sentry.web.decorators import has_access
 from sentry.web.frontend.groups import _get_group_list
-from sentry.web.helpers import render_to_response, \
-  get_project_list, render_to_string
+from sentry.web.helpers import render_to_response, render_to_string
 
 logger = logging.getLogger('sentry.errors.coreapi')
 
@@ -31,6 +30,34 @@ logger = logging.getLogger('sentry.errors.coreapi')
 @csrf_exempt
 @require_http_methods(['POST'])
 def store(request):
+    """
+    The primary endpoint for storing new events.
+
+    This will validate the client's authentication and data, and if
+    successfull pass on the payload to the internal database handler.
+
+    Authentication works in three flavors:
+
+    1. Explicit signed requests
+
+       These are implemented using the documented signed request protocol, and
+       require an authentication header which is signed using with the project
+       member's secret key.
+
+    2. Explicit trusted requests
+
+       Generally used for communications with client-side platforms (such as
+       JavaScript in the browser), they require the GET variables public_key
+       and project_id, as well as an HTTP_REFERER to be set from a trusted
+       domain.
+
+    3. Implicit trusted requests
+
+       Used by the Sentry core, they are only available from same-domain requests
+       and do not require any authentication information. They only require that
+       the user be authenticated, and a project_id be sent in the GET variables.
+
+    """
     try:
         auth_vars = extract_auth_vars(request)
         data = request.raw_post_data
@@ -48,12 +75,17 @@ def store(request):
         if server_version != '1.0' and not client:
             raise APIError('Client request error: Missing client version identifier.')
 
+        referrer = request.META.get('HTTP_REFERER')
+
         if auth_vars:
             project = project_from_auth_vars(auth_vars, data)
-        elif request.GET.get('api_key') and request.GET.get('project_id') and request.is_secure():
-            # ssl requests dont have to have signature verification
+        elif request.GET.get('api_key') and request.GET.get('project_id'):
+            # public requests only need referrer validation for CSRF
             project = project_from_api_key_and_id(request.GET['api_key'], request.GET['project_id'])
-        elif request.GET.get('project_id') and request.user.is_authenticated():
+            if not ProjectDomain.test(project, referrer):
+                raise APIUnauthorized()
+        elif request.GET.get('project_id') and request.user.is_authenticated() and \
+             is_same_domain(request.build_absolute_uri(), referrer):
             # authenticated users are simply trusted to provide the right id
             project = project_from_id(request)
         else:
@@ -192,9 +224,20 @@ def bookmark(request, project):
 @csrf_exempt
 @has_access
 def clear(request, project):
-    projects = get_project_list(request.user)
+    view_id = request.GET.get('view_id')
+    if view_id:
+        try:
+            view = View.objects.get(pk=view_id)
+        except View.DoesNotExist:
+            return HttpResponseBadRequest()
+    else:
+        view = None
 
-    event_list = Group.objects.filter(Q(project__in=projects.keys()) | Q(project__isnull=True))
+    _, event_list = _get_group_list(
+        request=request,
+        project=project,
+        view=view,
+    )
 
     event_list.update(status=1)
 
